==> haskell-cryptohash-cryptoapi-0.1.4-205-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptohash-cryptoapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cryptohash-cryptoapi
version:              0.1.4
visibility:           public
id:                   cryptohash-cryptoapi-0.1.4-HMNzMvLVvFQGHGhO9VY1l5
key:                  cryptohash-cryptoapi-0.1.4-HMNzMvLVvFQGHGhO9VY1l5
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             https://github.com/vincenthz/hs-cryptohash-cryptoapi
synopsis:             Crypto-api interfaces for cryptohash
description:          Crypto-api interfaces for cryptohash
category:             Cryptography
abi:                  f79acedbfe88a3a1ed0d39bb884bf96a
exposed:              True
exposed-modules:      Crypto.Hash.CryptoAPI
import-dirs:          /usr/lib/ghc-9.0.1/site-local/cryptohash-cryptoapi-0.1.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/cryptohash-cryptoapi-0.1.4
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/cryptohash-cryptoapi-0.1.4

hs-libraries:         HScryptohash-cryptoapi-0.1.4-HMNzMvLVvFQGHGhO9VY1l5
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    cereal-0.5.8.2-61j1a5W2ABqDRz8HqQdVx7
    crypto-api-0.13.3-K4D4TqlwTtyDpSHz3hLF4b
    cryptonite-0.29-19SjDRwWNox27CMfesQpq4
    memory-0.16.0-CGaPOmXCTce28vOCDDnDFr
    tagged-0.8.6.1-FL843C40q4d1DeuwYADr25

haddock-interfaces:
    /usr/share/doc/haskell-cryptohash-cryptoapi/html/cryptohash-cryptoapi.haddock

haddock-html:         /usr/share/doc/haskell-cryptohash-cryptoapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-cryptoapi-0.1.4-206-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptohash-cryptoapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cryptohash-cryptoapi
version:              0.1.4
visibility:           public
id:                   cryptohash-cryptoapi-0.1.4-8hQuxL2GtPeBSJvPzV9nif
key:                  cryptohash-cryptoapi-0.1.4-8hQuxL2GtPeBSJvPzV9nif
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             https://github.com/vincenthz/hs-cryptohash-cryptoapi
synopsis:             Crypto-api interfaces for cryptohash
description:          Crypto-api interfaces for cryptohash
category:             Cryptography
abi:                  c55443cb94a6a7d411e95c9452af959e
exposed:              True
exposed-modules:      Crypto.Hash.CryptoAPI
import-dirs:          /usr/lib/ghc-9.0.1/site-local/cryptohash-cryptoapi-0.1.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/cryptohash-cryptoapi-0.1.4
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/cryptohash-cryptoapi-0.1.4

hs-libraries:         HScryptohash-cryptoapi-0.1.4-8hQuxL2GtPeBSJvPzV9nif
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    cereal-0.5.8.2-61j1a5W2ABqDRz8HqQdVx7
    crypto-api-0.13.3-K4D4TqlwTtyDpSHz3hLF4b
    cryptonite-0.29-GRn4QfSajtp4ejYMImOiTS
    memory-0.16.0-CGaPOmXCTce28vOCDDnDFr
    tagged-0.8.6.1-FL843C40q4d1DeuwYADr25

haddock-interfaces:
    /usr/share/doc/haskell-cryptohash-cryptoapi/html/cryptohash-cryptoapi.haddock

haddock-html:         /usr/share/doc/haskell-cryptohash-cryptoapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
